@@ -77,12 +77,11 @@ void ApplyArchivedResult(const MTPDmessages_stickerSetInstallResultArchive &d) {
 	Local::writeInstalledStickers();
 	Local::writeArchivedStickers();
 
-	auto toast = Ui::Toast::Config();
-	toast.text = { tr::lng_stickers_packs_archived(tr::now) };
-	toast.maxWidth = toast.minWidth = st::stickersToastMaxWidth;
-	toast.multiline = true;
-	toast.padding = st::stickersToastPadding;
-	Ui::Toast::Show(toast);
+	Ui::Toast::Show(Ui::Toast::Config{
+		.text = { tr::lng_stickers_packs_archived(tr::now) },
+		.st = &st::stickersToast,
+		.multiline = true,
+	});
 //	Ui::show(Box<StickersBox>(archived, &Auth()), Ui::LayerOption::KeepOther);
 
 	Auth().data().notifyStickersUpdated();
