@@ -373,11 +373,8 @@ void Sandbox::readClients() {
 						toSend.append(_escapeFrom7bit(cmds.mid(from + 5, to - from - 5)));
 					}
 				} else if (cmd.startsWith(qsl("OPEN:"))) {
-					auto activateRequired = true;
-					if (cStartUrl().isEmpty()) {
-						startUrl = _escapeFrom7bit(cmds.mid(from + 5, to - from - 5)).mid(0, 8192);
-						activateRequired = StartUrlRequiresActivate(startUrl);
-					}
+					startUrl = _escapeFrom7bit(cmds.mid(from + 5, to - from - 5)).mid(0, 8192);
+					auto activateRequired = StartUrlRequiresActivate(startUrl);
 					if (activateRequired) {
 						execExternal("show");
 					}
