@@ -210,7 +210,9 @@ DeclareRefVar(base::Observable<void>, DownloadPathChanged);
 DeclareVar(bool, VoiceMsgPlaybackDoubled);
 DeclareVar(bool, SoundNotify);
 DeclareVar(bool, DesktopNotify);
+DeclareVar(bool, FlashBounceNotify);
 DeclareVar(bool, RestoreSoundNotifyFromTray);
+DeclareVar(bool, RestoreFlashBounceNotifyFromTray);
 DeclareVar(DBINotifyView, NotifyView);
 DeclareVar(bool, NativeNotifications);
 DeclareVar(int, NotificationsCount);
