@@ -328,6 +328,9 @@ public:
 	[[nodiscard]] virtual std::unique_ptr<HistoryView::Element> createView(
 		not_null<HistoryView::ElementDelegate*> delegate) = 0;
 
+	void updateDate(TimeId newDate);
+	[[nodiscard]] bool canUpdateDate() const;
+
 	virtual ~HistoryItem();
 
 	MsgId id;
