@@ -54,6 +54,9 @@ public:
 	virtual void elementShowPollResults(
 		not_null<PollData*> poll,
 		FullMsgId context) = 0;
+	virtual void elementShowTooltip(
+		const TextWithEntities &text,
+		Fn<void()> hiddenCallback) = 0;
 
 };
 
@@ -77,6 +80,9 @@ public:
 	void elementShowPollResults(
 		not_null<PollData*> poll,
 		FullMsgId context) override;
+	void elementShowTooltip(
+		const TextWithEntities &text,
+		Fn<void()> hiddenCallback) override;
 
 };
 
